@@ -28,6 +28,7 @@ The main file for the Crazyflie control application.
 """
 import logging
 import sys
+import usb
 
 import cfclient
 from cfclient.ui.pose_logger import PoseLogger
@@ -54,10 +55,12 @@ from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtCore import QDir
 from PyQt5.QtCore import QThread
 from PyQt5.QtCore import QUrl
+from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QAction
 from PyQt5.QtWidgets import QActionGroup
 from PyQt5.QtWidgets import QShortcut
 from PyQt5.QtGui import QDesktopServices
+from PyQt5.QtGui import QPalette
 from PyQt5.QtWidgets import QLabel
 from PyQt5.QtWidgets import QMenu
 from PyQt5.QtWidgets import QMessageBox
@@ -103,7 +106,7 @@ class MainUI(QtWidgets.QMainWindow, main_window_class):
     connectionDoneSignal = pyqtSignal(str)
     connectionFailedSignal = pyqtSignal(str, str)
     disconnectedSignal = pyqtSignal(str)
-    linkQualitySignal = pyqtSignal(int)
+    linkQualitySignal = pyqtSignal(float)
 
     _input_device_error_signal = pyqtSignal(str)
     _input_discovery_signal = pyqtSignal(object)
@@ -140,6 +143,15 @@ class MainUI(QtWidgets.QMainWindow, main_window_class):
                                        " fly.")
         self.statusBar().addWidget(self._statusbar_label)
 
+        #
+        # We use this hacky-trick to find out if we are in dark-mode and
+        # figure out what bgcolor to set from that. We always use the current
+        # palette forgreound.
+        #
+        self.textColor = self._statusbar_label.palette().color(QPalette.WindowText)
+        self.bgColor = self._statusbar_label.palette().color(QPalette.Background)
+        self.isDark = self.textColor.value() > self.bgColor.value()
+
         self.joystickReader = JoystickReader()
         self._active_device = ""
         # self.configGroup = QActionGroup(self._menu_mappings, exclusive=True)
@@ -185,7 +197,7 @@ class MainUI(QtWidgets.QMainWindow, main_window_class):
                 scan_button=self.scanButton))
 
         self._connectivity_manager.connect_button_clicked.connect(self._connect)
-        self._connectivity_manager.scan_button_clicked.connect(self._scan)
+        self._connectivity_manager.scan_button_clicked.connect(self._scan_from_button)
 
         self._disable_input = False
 
@@ -222,7 +234,7 @@ class MainUI(QtWidgets.QMainWindow, main_window_class):
         # Connect link quality feedback
         self.cf.link_quality_updated.add_callback(self.linkQualitySignal.emit)
         self.linkQualitySignal.connect(
-            lambda percentage: self.linkQualityBar.setValue(percentage))
+            lambda percentage: self.linkQualityBar.setValue(int(percentage)))
 
         # Parse the log configuration files
         self.logConfigReader = LogConfigReader(self.cf)
@@ -359,6 +371,9 @@ class MainUI(QtWidgets.QMainWindow, main_window_class):
             self._theme_group.addAction(node)
             self.menuThemes.addAction(node)
 
+        # We only want to warn about USB permission once
+        self._permission_warned = False
+
     def _set_address(self):
         address = 0xE7E7E7E7E7
         try:
@@ -598,6 +613,30 @@ class MainUI(QtWidgets.QMainWindow, main_window_class):
         self._update_ui_state()
         self.scanner.scanSignal.emit(address)
 
+    def _scan_from_button(self, address):
+        #
+        # Below we check if we can open the Crazyradio device.
+        # If it is there, but we have no permissions we inform the user, once,
+        # about how to install the udev rules.
+        #
+        if not self._permission_warned:
+            try:
+                radio = cflib.crtp.radiodriver.RadioManager.open(0)
+                radio.close()
+            except usb.core.USBError as e:
+                if e.errno == 13:  # Permission denied
+                    link = "<a href='https://www.bitcraze.io/documentation/repository/crazyflie-lib-python/master/installation/usb_permissions/'>Install USB Permissions</a>" # noqa
+                    msg = QMessageBox()
+                    msg.setIcon(QMessageBox.Information)
+                    msg.setTextFormat(Qt.RichText)
+                    msg.setText("Could not access Crazyradio")
+                    msg.setInformativeText(link)
+                    msg.setWindowTitle("Crazyradio permissions")
+                    msg.exec()
+                    self._permission_warned = True
+
+        self._scan(address)
+
     def _display_input_device_error(self, error):
         self.cf.close_link()
         QMessageBox.critical(self, "Input device error", error)
@@ -694,8 +733,8 @@ class MainUI(QtWidgets.QMainWindow, main_window_class):
 
     def _inputconfig_selected(self, checked):
         """Called when a new configuration has been selected from the menu. The
-        data in the menu object is a referance to the device QAction in parent
-        menu. This contains a referance to the raw device."""
+        data in the menu object is a reference to the device QAction in parent
+        menu. This contains a reference to the raw device."""
         if not checked:
             return
 
